/* #############################################################################
Main regression setup
############################################################################# */

/*
main setup: (for employment and actual hours)
- Interacting child_grp with the gender gap only (not the controls)
- More detailed child groups to capture heterogeneity we see in the data (see cutoffs definition)
	- none or adult (>=16); child below 16 in HH
- further definitions depend on sample creation and global reg_spec

- no time trends allowed
- no quarterly seasonality dummies
- no dummy for education sector workers in summer time

- employment:
	- comparing Jan & Sep 2019 & Jan 2020 to MCS and Sep 2020

- actual hours:
	- comparing Jul 2018 to MCS (week 5 & 10-16) 2020
*/

* Preliminaries
clear

* Directories *
cd "${git_workdir}"

* Log File
log using "${out_dir}/Germany_DiD_main.log", replace

* Load updated dataset
use "${local_data_encryp}/Germany_clean_paneldata.dta", clear



********************************************************************************
* Regressions: Broad Employment *
*********************************


// SPEC 2A: Broad Employment-- **unweighted** regression
* no time effects (no quarter FE, no summer education dummies, no gender specific linear trends)
est clear 

preserve

* Time Sample
keep if year>=$samp_yr

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.

* Population
reg broad_emp Dt##ib1.sex                                      i.birth_year_cat i.simp_migration i.educ i.married,  robust 
est store bench  
matrix table_bench = r(table) //store reg results


reg broad_emp Dt##ib1.sex   Dt##i.work_type                    i.birth_year_cat i.simp_migration i.educ i.married ,  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
reg broad_emp Dt##ib1.sex#ib0.child_grp                        i.birth_year_cat i.simp_migration i.educ i.married ,  robust 
est store kid
matrix table_kid = r(table) //store reg results


reg broad_emp Dt##ib1.sex#ib0.child_grp   Dt##i.work_type      i.birth_year_cat i.simp_migration i.educ i.married ,  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 



* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/Germany_DiD.xlsx" , sheet("Table 7b") modify  // replace first time around
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Population (bench)"
putexcel B2=table_bench[1,8] 
putexcel B3=table_bench[2,8] 
putexcel B4=table_bench[4,8] 

putexcel C1 =  "No Kids (bench)"
putexcel C2=table_kid[1,15]   
putexcel C3=table_kid[2,15] 
putexcel C4=table_kid[4,15] 

putexcel D1 =  "Kids < 16 (bench)"
putexcel D2=table_kid[1,16] 
putexcel D3=table_kid[2,16] 
putexcel D4=table_kid[4,16] 


//...and with occ controls

* Regression Results
putexcel E1 =  "Population (work type)"
putexcel E2=table_bench_occ[1,8] 
putexcel E3=table_bench_occ[2,8] 
putexcel E4=table_bench_occ[4,8] 

putexcel F1 =  "No Kids (work type)"
putexcel F2=table_kid_occ[1,15]   
putexcel F3=table_kid_occ[2,15] 
putexcel F4=table_kid_occ[4,15] 

putexcel G1 =  "Kids < 16 (work type)"
putexcel G2=table_kid_occ[1,16] 
putexcel G3=table_kid_occ[2,16] 
putexcel G4=table_kid_occ[4,16] 





********************************************************************************
* Regressions: Hours Last Week *
********************************

// SPEC 1A: Hours worked last week (daily hours and assumed 5 working days)
est clear 

preserve


* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.

* Population
reg hours Dt##ib1.sex                                      i.birth_year_cat i.simp_migration i.educ i.married,  robust 
est store bench  
matrix table_bench = r(table) //store reg results


reg hours Dt##ib1.sex   Dt##i.work_type                    i.birth_year_cat i.simp_migration i.educ i.married,  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
reg hours Dt##ib1.sex#ib0.child_grp                        i.birth_year_cat i.simp_migration i.educ i.married,  robust 
est store kid
matrix table_kid = r(table) //store reg results

reg hours Dt##ib1.sex#ib0.child_grp   Dt##i.work_type      i.birth_year_cat i.simp_migration i.educ i.married,  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/Germany_DiD.xlsx" , sheet("Table 8b") modify  // replace first time around
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Population (bench)"
putexcel B2=table_bench[1,8] 
putexcel B3=table_bench[2,8] 
putexcel B4=table_bench[4,8] 

putexcel C1 =  "No Kids (bench)"
putexcel C2=table_kid[1,15]   
putexcel C3=table_kid[2,15] 
putexcel C4=table_kid[4,15] 

putexcel D1 =  "Kids < 16 (bench)"
putexcel D2=table_kid[1,16] 
putexcel D3=table_kid[2,16] 
putexcel D4=table_kid[4,16] 


//...and with occ controls

* Regression Results
putexcel E1 =  "Population (work type)"
putexcel E2=table_bench_occ[1,8] 
putexcel E3=table_bench_occ[2,8] 
putexcel E4=table_bench_occ[4,8] 

putexcel F1 =  "No Kids (work type)"
putexcel F2=table_kid_occ[1,15]   
putexcel F3=table_kid_occ[2,15] 
putexcel F4=table_kid_occ[4,15] 

putexcel G1 =  "Kids < 16 (work type)"
putexcel G2=table_kid_occ[1,16] 
putexcel G3=table_kid_occ[2,16] 
putexcel G4=table_kid_occ[4,16] 


********************************************************************************
********************************************************************************

log close

